CardscanPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • CardscanPlatform
Implementers

Constructors

CardscanPlatform()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

isSupported() Future<bool>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
scanCard(CardScanOptions options) Future<CardScanResult?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance CardscanPlatform
getter/setter pair