CardScanOptions class final
Constructors
- CardScanOptions({bool enableEnterManually = true, bool enableNameExtraction = false, bool enableExpiryExtraction = true})
-
const
Properties
- enableEnterManually → bool
-
final
- enableExpiryExtraction → bool
-
final
- enableNameExtraction → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited