CardScanResult class final
Constructors
- CardScanResult({required String? cardNumber, required String? expiryMonth, required String? expiryYear, required String? cardholderName, required String? networkName})
-
const
-
CardScanResult.fromMap(Map<
String, Object?> map) -
factory
Properties
- cardholderName → String?
-
final
- cardNumber → String?
-
final
- expiryMonth → String?
-
final
- expiryYear → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- networkName → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited